package sgc.portal.cs.cs0101.persistence;
import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0101.dto.CS01010001USearch;
import sgc.portal.cs.cs0101.model.CS01010001U;

import java.util.List;

@Mapper
public interface CS01010001UMapper {
	
	//공지사항 조회
	List<EasyHashMap<String, Object>> selectTcsNotiList(CS01010001USearch search);
	EasyHashMap<String, Object> selectTcsNotiPopList(CS01010001USearch search);
	List<EasyHashMap<String, Object>> selectFileList(CS01010001USearch search);
	
	//공지사항 등록 변경 삭제
	void insertTcsNoti(CS01010001U cS01010001U);
	void updateTcsNoti(CS01010001U cS01010001U);
	void deleteTcsNoti(CS01010001U cS01010001U);
	int selectTcsNotiCount(CS01010001U cS01010001U);
	int selectTcsNotiNotiAflIdCount(CS01010001U cS01010001U);
	void deleteTcsNotiNotiAflId(CS01010001U cS01010001U);
	
	String selectTcsNotiSeq(CS01010001U cS01010001U);
	void updateAflId(CS01010001U cS01010001U);
}
